pygeodesy.deprecated.classes.JacobiConformal

Package pygeodesy :: Package deprecated :: Module classes :: Class JacobiConformal |
[frames] | no frames]

# Class JacobiConformal

                    object --+
                             |
                  named._Named --+
                                 |
                  named._NamedBase --+
                                     |
                  named._NamedEnumItem --+
                                         |
    triaxials.bases._UnOrderedTriaxialBase --+
                                             |
          triaxials.bases._OrderedTriaxialBase --+
                                                 |
                      triaxials.triaxial5.Triaxial --+
                                                     |
                         triaxials.triaxial5.Conformal --+
                                                         |
                                                        JacobiConformal

DEPRECATED on 2025.10.25, use class Conformal.

Instance Methods
__init__(self, *args, **kwds) New ordered Triaxial, Triaxial3, Conformal or Conformal3. |
Inherited from `triaxials.triaxial5.Conformal`: `x`, `xR`, `xR_`, `xy`, `xyR2`, `xyR2_`, `y`, `yR`, `yR_` Inherited from `triaxials.triaxial5.Triaxial`: `forwardBetaOmega`, `forwardBetaOmega_`, `forwardCartesian`, `forwardLatLon`, `forwardLatLon_`, `reverseBetaOmega`, `reverseCartesian`, `reverseLatLon` Inherited from `triaxials.bases._UnOrderedTriaxialBase`: `areaKT`, `area_p`, `hartzell4`, `height4`, `normal3d`, `normal4`, `sideOf`, `toBiaxial`, `toEllipsoid`, `toStr` Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `triaxials.triaxial5.Conformal`: `xyQ2`, `xyQR2` Inherited from `triaxials.bases._OrderedTriaxialBase`: `area` Inherited from `triaxials.bases._UnOrderedTriaxialBase`: `R2`, `R3`, `Rauthalic`, `Rvolumetric`, `a`, `a2`, `abc3`, `areaRG`, `b`, `b2`, `c`, `c2`, `e2ab`, `e2ac`, `e2bc`, `isFlat`, `isOblate`, `isOrdered`, `isProlate`, `isSpherical`, `perimeter4ab`, `perimeter4ac`, `perimeter4bc`, `unOrdered`, `volume` Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, *args, **kwds) (Constructor) |
New ordered Triaxial, Triaxial3, Conformal or Conformal3. Arguments: `a_triaxial` - Largest semi-axis (`scalar`, conventionally in `meter`) or an other Triaxial or Triaxial_ instance. `b` - Middle semi-axis (`meter`, same units as `a`), required if `a_triaxial is scalar`, ignored otherwise. `c` - Smallest semi-axis (`meter`, like `b`). `name` - Optional `name=NN` (`str`). Raises: `TriaxialError` - Semi-axes unordered, spherical or invalid. Overrides: object.__init__ (inherited documentation)